icenet.data.interfaces package
==============================

Submodules
----------

icenet.data.interfaces.cds module
---------------------------------

.. automodule:: icenet.data.interfaces.cds
    :members:
    :undoc-members:
    :show-inheritance:

icenet.data.interfaces.downloader module
----------------------------------------

.. automodule:: icenet.data.interfaces.downloader
    :members:
    :undoc-members:
    :show-inheritance:

icenet.data.interfaces.esgf module
----------------------------------

.. automodule:: icenet.data.interfaces.esgf
    :members:
    :undoc-members:
    :show-inheritance:

icenet.data.interfaces.mars module
----------------------------------

.. automodule:: icenet.data.interfaces.mars
    :members:
    :undoc-members:
    :show-inheritance:

icenet.data.interfaces.utils module
-----------------------------------

.. automodule:: icenet.data.interfaces.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: icenet.data.interfaces
    :members:
    :undoc-members:
    :show-inheritance:
